@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -382,14 +382,14 @@ class DebugBase(object):
             frame = sys._getframe().f_back  # Skip set_trace method
         
         if sys.version_info[0] == 2:
-            stopOnHandleLine = self._dbgClient.handleLine.func_code
+            stopOnHandleCommand = self._dbgClient.handleJsonCommand.func_code
         else:
-            stopOnHandleLine = self._dbgClient.handleLine.__code__
+            stopOnHandleCommand = self._dbgClient.handleJsonCommand.__code__
         
         frame.f_trace = self.trace_dispatch
         while frame.f_back is not None:
-            # stop at erics debugger frame or a threading bootstrap
-            if (frame.f_back.f_code == stopOnHandleLine):
+            # stop at eric's debugger frame or a threading bootstrap
+            if (frame.f_back.f_code == stopOnHandleCommand):
                 frame.f_trace = self.trace_dispatch
                 break
             
@@ -796,7 +796,9 @@ class DebugBase(object):
         """
         exctype, excval, exctb = excinfo
         
-        if exctype in [GeneratorExit, StopIteration, SystemExit]:
+        if ((exctype in [GeneratorExit, StopIteration] and
+             unhandled is False) or
+                exctype == SystemExit):
             # ignore these
             return
         
