@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,14 +15,14 @@ import hashlib
 import base64
 
 from PyQt5.QtCore import pyqtSignal, Qt, QObject, QByteArray, QDateTime, \
-    QUrl, QCryptographicHash, QFile, QIODevice, QTextStream, QDate, QTime, \
-    qVersion
+    QUrl, QCryptographicHash, QFile, QIODevice, QTextStream, QDate, QTime
 from PyQt5.QtNetwork import QNetworkReply
 
 from E5Gui import E5MessageBox
 
 import Utilities
 import Preferences
+from Globals import qVersionTuple
 
 
 class AdBlockSubscription(QObject):
@@ -113,7 +113,7 @@ class AdBlockSubscription(QObject):
         if url.path() != "subscribe":
             return
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             from PyQt5.QtCore import QUrlQuery
             urlQuery = QUrlQuery(url)
             self.__title = QUrl.fromPercentEncoding(
@@ -185,7 +185,7 @@ class AdBlockSubscription(QObject):
         if self.__lastUpdate.isValid():
             queryItems.append(("lastUpdate",
                                self.__lastUpdate.toString(Qt.ISODate)))
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             from PyQt5.QtCore import QUrlQuery
             query = QUrlQuery()
             query.setQueryItems(queryItems)
