@@ -469,7 +469,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
                                  QNetworkRequest.AlwaysNetwork)
             reply = self.__networkManager.get(request)
-            reply.finished.connect(self.__downloadFileDone)
+            reply.finished.connect(lambda: self.__downloadFileDone(reply))
             reply.downloadProgress.connect(self.__downloadProgress)
             self.__replies.append(reply)
         else:
@@ -481,17 +481,19 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                     """ from {0}.</p><p>Error: {1}</p>"""
                 ).format(url, self.tr("Computer is offline.")))
     
-    def __downloadFileDone(self):
+    def __downloadFileDone(self, reply):
         """
         Private method called, after the file has been downloaded
         from the Internet.
+        
+        @param reply reference to the reply object of the download
+        @type QNetworkReply
         """
         self.__updateButton.setEnabled(True)
         self.__downloadCancelButton.setEnabled(False)
         self.__onlineStateChanged(self.__isOnline())
         
         ok = True
-        reply = self.sender()
         if reply in self.__replies:
             self.__replies.remove(reply)
         if reply.error() != QNetworkReply.NoError:
@@ -886,15 +888,22 @@ def PluginRepositoryDownloadCleanup(quiet=False):
         if not os.path.isfile(os.path.join(downloadPath, pluginFile)):
             continue
         
-        pluginName, pluginVersion = \
-            pluginFile.replace(".zip", "").rsplit("-", 1)
-        pluginVersionList = re.split("[._-]", pluginVersion)
-        for index in range(len(pluginVersionList)):
-            try:
-                pluginVersionList[index] = int(pluginVersionList[index])
-            except ValueError:
-                # use default of 0
-                pluginVersionList[index] = 0
+        try:
+            pluginName, pluginVersion = \
+                pluginFile.replace(".zip", "").rsplit("-", 1)
+            pluginVersionList = re.split("[._-]", pluginVersion)
+            for index in range(len(pluginVersionList)):
+                try:
+                    pluginVersionList[index] = int(pluginVersionList[index])
+                except ValueError:
+                    # use default of 0
+                    pluginVersionList[index] = 0
+        except ValueError:
+            # rsplit() returned just one entry, i.e. file name doesn't contain
+            # version info separated by '-'
+            # => assume version 0.0.0
+            pluginName = pluginFile.replace(".zip", "")
+            pluginVersionList = [0, 0, 0]
         
         if pluginName not in downloads:
             downloads[pluginName] = []
