@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,7 +21,10 @@ class MiscellaneousChecker(object):
     Codes = [
         "M101", "M102",
         "M111", "M112",
-        "M121",
+        "M131", "M132",
+        
+        "M191", "M192", "M193", "M194",
+        "M195", "M196", "M197", "M198",
         
         "M601",
         "M611", "M612", "M613",
@@ -32,12 +35,19 @@ class MiscellaneousChecker(object):
         
         "M801",
         "M811",
+        "M821", "M822",
         
         "M901",
     ]
     
     Formatter = Formatter()
     FormatFieldRegex = re.compile(r'^((?:\s|.)*?)(\..*|\[.*\])?$')
+    
+    BuiltinsWhiteList = [
+        "__name__",
+        "__doc__",
+        "credits",
+    ]
 
     def __init__(self, source, filename, select, ignore, expected, repeat,
                  args):
@@ -67,10 +77,17 @@ class MiscellaneousChecker(object):
         self.__source = source[:]
         self.__args = args
         
-        self.__blindExceptRegex = re.compile(
-            r'(\bexcept:)')                             # __IGNORE_WARNING__
         self.__pep3101FormatRegex = re.compile(
             r'^(?:[^\'"]*[\'"][^\'"]*[\'"])*\s*%|^\s*%')
+        
+        if sys.version_info >= (3, 0):
+            import builtins
+            self.__builtins = [b for b in dir(builtins)
+                               if b not in self.BuiltinsWhiteList]
+        else:
+            import __builtin__
+            self.__builtins = [b for b in dir(__builtin__)
+                               if b not in self.BuiltinsWhiteList]
 
         # statistics counters
         self.counters = {}
@@ -81,7 +98,9 @@ class MiscellaneousChecker(object):
         checkersWithCodes = [
             (self.__checkCoding, ("M101", "M102")),
             (self.__checkCopyright, ("M111", "M112")),
-            (self.__checkBlindExcept, ("M121",)),
+            (self.__checkBuiltins, ("M131", "M132")),
+            (self.__checkComprehensions, ("M191", "M192", "M193", "M194",
+                                          "M195", "M196", "M197", "M198")),
             (self.__checkPep3101, ("M601",)),
             (self.__checkFormatString, ("M611", "M612", "M613",
                                         "M621", "M622", "M623", "M624", "M625",
@@ -89,6 +108,7 @@ class MiscellaneousChecker(object):
             (self.__checkFuture, ("M701", "M702")),
             (self.__checkPrintStatements, ("M801",)),
             (self.__checkTuple, ("M811", )),
+            (self.__checkMutableDefault, ("M821", "M822")),
         ]
         
         self.__defaultArgs = {
@@ -97,6 +117,10 @@ class MiscellaneousChecker(object):
                 "MinFilesize": 0,
                 "Author": "",
             },
+            "BuiltinsChecker": {
+                "str": ["unicode", ],
+                "chr": ["unichr", ],
+            }
         }
         
         self.__checkers = []
@@ -258,15 +282,6 @@ class MiscellaneousChecker(object):
             if not copyrightAuthorRe.search(topOfSource):
                 self.__error(0, 0, "M112")
     
-    def __checkBlindExcept(self):
-        """
-        Private method to check for blind except statements.
-        """
-        for lineno, line in enumerate(self.__source):
-            match = self.__blindExceptRegex.search(line)
-            if match:
-                self.__error(lineno, match.start(), "M121")
-    
     def __checkPrintStatements(self):
         """
         Private method to check for print statements.
@@ -290,10 +305,10 @@ class MiscellaneousChecker(object):
         """
         Private method to check the __future__ imports.
         """
-        expectedImports = set(
-            [i.strip()
-             for i in self.__args.get("FutureChecker", "").split(",")
-             if bool(i.strip())])
+        expectedImports = {
+            i.strip()
+            for i in self.__args.get("FutureChecker", "").split(",")
+            if bool(i.strip())}
         if len(expectedImports) == 0:
             # nothing to check for; disabling the check
             return
@@ -305,7 +320,7 @@ class MiscellaneousChecker(object):
         for node in ast.walk(self.__tree):
             if (isinstance(node, ast.ImportFrom) and
                     node.module == '__future__'):
-                imports |= set(name.name for name in node.names)
+                imports |= {name.name for name in node.names}
             elif isinstance(node, ast.Expr):
                 if not isinstance(node.value, ast.Str):
                     hasCode = True
@@ -394,7 +409,7 @@ class MiscellaneousChecker(object):
                     else:
                         names.add(fieldMatch.group(1))
                 
-                keywords = set(keyword.arg for keyword in call.keywords)
+                keywords = {keyword.arg for keyword in call.keywords}
                 numArgs = len(call.args)
                 if strArgs:
                     numArgs -= 1
@@ -477,6 +492,126 @@ class MiscellaneousChecker(object):
             return set(), False, False
         else:
             return fields, implicit, explicit
+    
+    def __checkBuiltins(self):
+        """
+        Private method to check, if built-ins are shadowed.
+        """
+        ignoreBuiltinAssignments = self.__args.get(
+            "BuiltinsChecker", self.__defaultArgs["BuiltinsChecker"])
+        
+        for node in ast.walk(self.__tree):
+            if isinstance(node, ast.Assign):
+                # assign statement
+                for element in node.targets:
+                    if isinstance(element, ast.Name) and \
+                       element.id in self.__builtins:
+                        value = node.value
+                        if isinstance(value, ast.Name) and \
+                           element.id in ignoreBuiltinAssignments and \
+                           value.id in ignoreBuiltinAssignments[element.id]:
+                            # ignore compatibility assignments
+                            continue
+                        self.__error(element.lineno - 1, element.col_offset,
+                                     "M131", element.id)
+                    elif isinstance(element, (ast.Tuple, ast.List)):
+                        for tupleElement in element.elts:
+                            if isinstance(tupleElement, ast.Name) and \
+                               tupleElement.id in self.__builtins:
+                                self.__error(tupleElement.lineno - 1,
+                                             tupleElement.col_offset,
+                                             "M131", tupleElement.id)
+            elif isinstance(node, ast.For):
+                # for loop
+                target = node.target
+                if isinstance(target, ast.Name) and \
+                   target.id in self.__builtins:
+                    self.__error(target.lineno - 1, target.col_offset,
+                                 "M131", target.id)
+                elif isinstance(target, (ast.Tuple, ast.List)):
+                    for element in target.elts:
+                        if isinstance(element, ast.Name) and \
+                           element.id in self.__builtins:
+                            self.__error(element.lineno - 1,
+                                         element.col_offset,
+                                         "M131", element.id)
+            elif isinstance(node, ast.FunctionDef):
+                # function definition
+                if sys.version_info >= (3, 0):
+                    for arg in node.args.args:
+                        if isinstance(arg, ast.arg) and \
+                           arg.arg in self.__builtins:
+                            self.__error(arg.lineno - 1, arg.col_offset,
+                                         "M132", arg.arg)
+                else:
+                    for arg in node.args.args:
+                        if isinstance(arg, ast.Name) and \
+                           arg.id in self.__builtins:
+                            self.__error(arg.lineno - 1, arg.col_offset,
+                                         "M132", arg.id)
+    
+    def __checkComprehensions(self):
+        """
+        Private method to check some comprehension related things.
+        """
+        for node in ast.walk(self.__tree):
+            if (isinstance(node, ast.Call) and
+               len(node.args) == 1 and
+               isinstance(node.func, ast.Name)):
+                if (isinstance(node.args[0], ast.GeneratorExp) and
+                        node.func.id in ('list', 'set', 'dict')):
+                    errorCode = {
+                        "list": "M191",
+                        "set": "M192",
+                        "dict": "M193",
+                    }[node.func.id]
+                    self.__error(node.lineno - 1, node.col_offset, errorCode)
+
+                elif (isinstance(node.args[0], ast.ListComp) and
+                      node.func.id in ('set', 'dict')):
+                    errorCode = {
+                        'set': 'M194',
+                        'dict': 'M195',
+                    }[node.func.id]
+                    self.__error(node.lineno - 1, node.col_offset, errorCode)
+
+                elif (isinstance(node.args[0], ast.List) and
+                      node.func.id in ('set', 'dict')):
+                    errorCode = {
+                        'set': 'M196',
+                        'dict': 'M197',
+                    }[node.func.id]
+                    self.__error(node.lineno - 1, node.col_offset, errorCode)
+
+                elif (isinstance(node.args[0], ast.ListComp) and
+                      node.func.id in ('all', 'any', 'frozenset', 'max', 'min',
+                                       'sorted', 'sum', 'tuple',)):
+                    self.__error(node.lineno - 1, node.col_offset, "M198",
+                                 node.func.id)
+    
+    def __checkMutableDefault(self):
+        """
+        Private method to check for use of mutable types as default arguments.
+        """
+        mutableTypes = [
+            ast.Call,
+            ast.Dict,
+            ast.List,
+            ast.Set,
+        ]
+        
+        for node in ast.walk(self.__tree):
+            if isinstance(node, ast.FunctionDef):
+                for default in node.args.defaults:
+                    if any(isinstance(default, mutableType)
+                           for mutableType in mutableTypes):
+                        typeName = type(default).__name__
+                        if isinstance(default, ast.Call):
+                            errorCode = "M822"
+                        else:
+                            errorCode = "M821"
+                        self.__error(default.lineno - 1, default.col_offset,
+                                     errorCode, typeName)
 
 
 class TextVisitor(ast.NodeVisitor):
