@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -316,6 +316,8 @@ _messages = {
         "private function/method is missing a docstring"),
     "D205": QCoreApplication.translate(
         "DocStyleChecker", "private class is missing a docstring"),
+    "D206": QCoreApplication.translate(
+        "DocStyleChecker", "class docstring is still a default string"),
     "D221": QCoreApplication.translate(
         "DocStyleChecker",
         "leading quotes of docstring not on separate line"),
@@ -370,6 +372,24 @@ _messages = {
         "DocStyleChecker",
         "docstring contains a @exception line but function/method doesn't"
         " raise an exception"),
+    "D252": QCoreApplication.translate(
+        "DocStyleChecker",
+        "raised exception '{0}' is not documented in docstring"),
+    "D253": QCoreApplication.translate(
+        "DocStyleChecker",
+        "documented exception '{0}' is not raised"),
+    "D260": QCoreApplication.translate(
+        "DocStyleChecker",
+        "docstring does not contain a @signal line but class defines signals"),
+    "D261": QCoreApplication.translate(
+        "DocStyleChecker",
+        "docstring contains a @signal line but class doesn't define signals"),
+    "D262": QCoreApplication.translate(
+        "DocStyleChecker",
+        "defined signal '{0}' is not documented in docstring"),
+    "D263": QCoreApplication.translate(
+        "DocStyleChecker",
+        "documented signal '{0}' is not defined"),
     
     "D901": QCoreApplication.translate(
         "DocStyleChecker", "{0}: {1}"),
@@ -703,6 +723,10 @@ _messages_sample_args = {
     "E901": ["SyntaxError", "Invalid Syntax"],
     "E902": ["IOError"],
     "D232": ["public"],
+    "D252": ["RuntimeError"],
+    "D253": ["RuntimeError"],
+    "D262": ["buttonClicked"],
+    "D263": ["buttonClicked"],
     "D901": ["SyntaxError", "Invalid Syntax"],
     "C101": ["foo.bar", "42"],
     "C111": [42],
