@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # pylint: disable=C0103
 
@@ -188,5 +188,10 @@ def __jsSyntaxCheck(file, codestring):
         cline = min(len(codestring.splitlines()), int(line)) - 1
         code = codestring.splitlines()[cline]
         return [{'error': (fn, int(line), 0, code, error)}]
+    except IndexError:
+        error = "Incomplete source file"
+        splittedCode = codestring.splitlines()
+        return [{'error': (file, len(splittedCode) + 1, len(splittedCode[-1]),
+                           splittedCode[-1], error)}]
     
     return [{}]
