@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -26,6 +26,7 @@ from E5Gui import E5MessageBox
 from .Ui_SvnStatusDialog import Ui_SvnStatusDialog
 
 import Preferences
+from Globals import strToQByteArray
 
 
 class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
@@ -558,7 +559,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
             self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(inputTxt)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
