@@ -76,6 +76,13 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         
         self.jsOpenWindowsCheckBox.setChecked(
             Preferences.getWebBrowser("JavaScriptCanOpenWindows"))
+        try:
+            # Qt 5.10
+            self.jsActivateWindowsCheckBox.setChecked(
+                Preferences.getWebBrowser(
+                    "AllowWindowActivationFromJavaScript"))
+        except KeyError:
+            self.jsActivateWindowsCheckBox.setEnabled(False)
         self.jsClipboardCheckBox.setChecked(
             Preferences.getWebBrowser("JavaScriptCanAccessClipboard"))
         self.pluginsCheckBox.setChecked(
@@ -173,6 +180,12 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
                 Preferences.getWebBrowser("AllowRunningInsecureContent"))
         except KeyError:
             self.insecureContentsCheckBox.setEnabled(False)
+        try:
+            # Qt 5.9
+            self.insecureGeolocationCheckBox.setChecked(
+                Preferences.getWebBrowser("AllowGeolocationOnInsecureOrigins"))
+        except KeyError:
+            self.insecureGeolocationCheckBox.setEnabled(False)
         
         try:
             # Qt 5.8
@@ -228,6 +241,10 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         Preferences.setWebBrowser(
             "JavaScriptCanOpenWindows",
             self.jsOpenWindowsCheckBox.isChecked())
+        if self.jsActivateWindowsCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "AllowWindowActivationFromJavaScript",
+                self.jsActivateWindowsCheckBox.isChecked())
         Preferences.setWebBrowser(
             "JavaScriptCanAccessClipboard",
             self.jsClipboardCheckBox.isChecked())
@@ -319,6 +336,10 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             Preferences.setWebBrowser(
                 "AllowRunningInsecureContent",
                 self.insecureContentsCheckBox.isChecked())
+        if self.insecureGeolocationCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "AllowGeolocationOnInsecureOrigins",
+                self.insecureGeolocationCheckBox.isChecked())
         
         if self.printBackgroundCheckBox.isEnabled():
             Preferences.setWebBrowser(
