@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -745,14 +745,18 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         if self.project.getProjectLanguage() in \
                 ["Python", "Python2", "Python3"]:
             if self.project.getProjectType() in ["Qt4", ]:
-                self.uicompiler = Utilities.generatePyQtToolPath('pyuic4')
+                self.uicompiler = Utilities.generatePyQtToolPath(
+                    'pyuic4', ["py3uic4", "py2uic4"])
             elif self.project.getProjectType() in ["PyQt5"]:
-                self.uicompiler = Utilities.generatePyQtToolPath('pyuic5')
+                self.uicompiler = Utilities.generatePyQtToolPath(
+                    'pyuic5', ["py3uic5", "py2uic5"])
             elif self.project.getProjectType() in ["E6Plugin"]:
                 if PYQT_VERSION < 0x050000:
-                    self.uicompiler = Utilities.generatePyQtToolPath('pyuic4')
+                    self.uicompiler = Utilities.generatePyQtToolPath(
+                        'pyuic4', ["py3uic4", "py2uic4"])
                 else:
-                    self.uicompiler = Utilities.generatePyQtToolPath('pyuic5')
+                    self.uicompiler = Utilities.generatePyQtToolPath(
+                        'pyuic5', ["py3uic5", "py2uic5"])
             elif self.project.getProjectType() == "PySide":
                 self.uicompiler = \
                     Utilities.generatePySideToolPath('pyside-uic')
