@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,14 +41,18 @@ class EditorAssembly(QWidget):
         self.__layout.setContentsMargins(0, 0, 0, 0)
         self.__layout.setSpacing(1)
         
+        from .EditorButtonsWidget import EditorButtonsWidget
+        from .Editor import Editor
+        
+        self.__editor = Editor(dbs, fn, vm, filetype, editor, tv)
+        self.__buttonsWidget = EditorButtonsWidget(self.__editor, self)
         self.__globalsCombo = QComboBox()
         self.__membersCombo = QComboBox()
-        from .Editor import Editor
-        self.__editor = Editor(dbs, fn, vm, filetype, editor, tv)
         
-        self.__layout.addWidget(self.__globalsCombo, 0, 0)
-        self.__layout.addWidget(self.__membersCombo, 0, 1)
-        self.__layout.addWidget(self.__editor, 1, 0, 1, -1)
+        self.__layout.addWidget(self.__buttonsWidget, 1, 0, -1, 1)
+        self.__layout.addWidget(self.__globalsCombo, 0, 1)
+        self.__layout.addWidget(self.__membersCombo, 0, 2)
+        self.__layout.addWidget(self.__editor, 1, 1, 1, -1)
         
         self.__module = None
         
