@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,7 +13,7 @@ from __future__ import unicode_literals
 import os
 
 from PyQt5.QtCore import QObject, QThread, QMutex, QProcess, \
-    Qt, pyqtSignal
+    Qt, pyqtSignal, QCoreApplication
 from PyQt5.QtWidgets import QApplication
 
 from E5Gui import E5MessageBox
@@ -244,16 +244,6 @@ class VersionControl(QObject):
         """
         raise RuntimeError('Not implemented')
         
-    def vcsLog(self, name):
-        """
-        Public method used to view the log of a file/directory in the vcs.
-        
-        @param name file/directory name to show the log for (string)
-        @exception RuntimeError to indicate that this method must be
-            implemented by a subclass
-        """
-        raise RuntimeError('Not implemented')
-        
     def vcsLogBrowser(self, name, isFile=False):
         """
         Public method used to view the log of a file/directory in the vcs
@@ -534,15 +524,15 @@ class VersionControl(QObject):
         if key in self.interestingDataKeys:
             self.otherData[key] = value
         
-    def vcsSetDataFromDict(self, dict):
+    def vcsSetDataFromDict(self, dictionary):
         """
         Public method used to set entries in the otherData dictionary.
         
-        @param dict dictionary to pick entries from
+        @param dictionary dictionary to pick entries from
         """
         for key in self.interestingDataKeys:
-            if key in dict:
-                self.otherData[key] = dict[key]
+            if key in dictionary:
+                self.otherData[key] = dictionary[key]
         
     #####################################################################
     ## below are some utility methods
@@ -572,8 +562,10 @@ class VersionControl(QObject):
         if not procStarted:
             E5MessageBox.critical(
                 None,
-                self.tr('Process Generation Error'),
-                self.tr(
+                QCoreApplication.translate(
+                    "VersionControl", 'Process Generation Error'),
+                QCoreApplication.translate(
+                    "VersionControl",
                     'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
                 ).format(program))
@@ -703,7 +695,9 @@ class VersionControl(QObject):
             self.statusMonitorThread = None
             self.__statusMonitorStatus(
                 "off",
-                self.tr("Repository status checking is switched off"))
+                QCoreApplication.translate(
+                    "VersionControl",
+                    "Repository status checking is switched off"))
     
     def setStatusMonitorInterval(self, interval, project):
         """
