@@ -125,8 +125,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         """
         Public method to stop the download manager.
         """
-        self.__saveTimer.changeOccurred()
-        self.__saveTimer.saveIfNeccessary()
+        self.save()
         self.close()
     
     def activeDownloads(self):
@@ -174,23 +173,26 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             return
         
         # Safe Browsing
-        threatLists = WebBrowserWindow.safeBrowsingManager().lookupUrl(url)
-        if threatLists:
-            threatMessages = WebBrowserWindow.safeBrowsingManager()\
-                .getThreatMessages(threatLists)
-            res = E5MessageBox.warning(
-                WebBrowserWindow.getWindow(),
-                self.tr("Suspicuous URL detected"),
-                self.tr("<p>The URL <b>{0}</b> was found in the Safe Browsing"
-                        " database.</p>{1}").format(url.toString(),
-                                                    "".join(threatMessages)),
-                E5MessageBox.StandardButtons(
-                    E5MessageBox.Abort |
-                    E5MessageBox.Ignore),
-                E5MessageBox.Abort)
-            if res == E5MessageBox.Abort:
-                downloadItem.cancel()
-                return
+        from WebBrowser.SafeBrowsing.SafeBrowsingManager import \
+            SafeBrowsingManager
+        if SafeBrowsingManager.isEnabled():
+            threatLists = WebBrowserWindow.safeBrowsingManager().lookupUrl(url)
+            if threatLists:
+                threatMessages = WebBrowserWindow.safeBrowsingManager()\
+                    .getThreatMessages(threatLists)
+                res = E5MessageBox.warning(
+                    WebBrowserWindow.getWindow(),
+                    self.tr("Suspicuous URL detected"),
+                    self.tr("<p>The URL <b>{0}</b> was found in the Safe"
+                            " Browsing database.</p>{1}").format(
+                        url.toString(), "".join(threatMessages)),
+                    E5MessageBox.StandardButtons(
+                        E5MessageBox.Abort |
+                        E5MessageBox.Ignore),
+                    E5MessageBox.Abort)
+                if res == E5MessageBox.Abort:
+                    downloadItem.cancel()
+                    return
         
         from .DownloadItem import DownloadItem
         itm = DownloadItem(downloadItem, parent=self)
@@ -339,20 +341,31 @@ class DownloadManager(QDialog, Ui_DownloadManager):
         pos = Preferences.getWebBrowser("DownloadManagerPosition")
         self.move(pos)
         
-        downloads = Preferences.getWebBrowser("DownloadManagerDownloads")
-        for download in downloads:
-            if not download[0].isEmpty() and \
-               download[1] != "":
-                from .DownloadItem import DownloadItem
-                itm = DownloadItem(parent=self)
-                itm.setData(download)
-                self.__addItem(itm, append=True)
-        self.cleanupButton.setEnabled(
-            (len(self.__downloads) - self.activeDownloads()) > 0)
+        from WebBrowser.WebBrowserWindow import WebBrowserWindow
+        if not WebBrowserWindow.isPrivate():
+            downloads = Preferences.getWebBrowser("DownloadManagerDownloads")
+            for download in downloads:
+                if not download["URL"].isEmpty() and \
+                   bool(download["Location"]):
+                    from .DownloadItem import DownloadItem
+                    itm = DownloadItem(parent=self)
+                    itm.setData(download)
+                    self.__addItem(itm, append=True)
+            self.cleanupButton.setEnabled(
+                (len(self.__downloads) - self.activeDownloads()) > 0)
         
         self.__loaded = True
         self.__updateActiveItemCount()
     
+    def closeEvent(self, evt):
+        """
+        Protected event handler for the close event.
+        
+        @param evt reference to the close event
+        @type QCloseEvent
+        """
+        self.save()
+    
     def cleanup(self):
         """
         Public slot to cleanup the downloads.
