@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -77,6 +77,15 @@ class SslErrorExceptionsDialog(QDialog, Ui_SslErrorExceptionsDialog):
         except AttributeError:
             # the value was added in Qt 5.7
             pass
+        try:
+            self.__errorDescriptions[
+                QWebEngineCertificateError.CertificateTransparencyRequired] = \
+                self.tr("Certificate Transparency was required for this"
+                        " connection, but the server did not provide"
+                        " information that complied with the policy.")
+        except AttributeError:
+            # the value was added in Qt 5.8
+            pass
         
         for host, errors in errorsDict.items():
             itm = QTreeWidgetItem(self.errorsTree, [host])
