@@ -110,8 +110,11 @@ class WebBrowserPage(QWebEnginePage):
         
         # Safe Browsing
         self.__badSite = False
-        if url.scheme() not in \
-           WebBrowserWindow.safeBrowsingManager().getIgnoreSchemes():
+        from WebBrowser.SafeBrowsing.SafeBrowsingManager import \
+            SafeBrowsingManager
+        if SafeBrowsingManager.isEnabled() and \
+            url.scheme() not in \
+                SafeBrowsingManager.getIgnoreSchemes():
             threatLists = WebBrowserWindow.safeBrowsingManager().lookupUrl(url)
             if threatLists:
                 threatMessages = WebBrowserWindow.safeBrowsingManager()\
