@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ from __future__ import unicode_literals
 import os
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QUrl, QDir, QFile, \
-    QFileDevice, QTemporaryFile, qVersion
+    QFileDevice, QTemporaryFile
 from PyQt5.QtGui import QIcon, QPixmap, QPainter
 from PyQt5.QtWidgets import QWidget, QHBoxLayout, QMenu, QToolButton, \
     QDialog, QApplication
@@ -33,6 +33,7 @@ import UI.PixmapCache
 import Utilities
 import Preferences
 import Globals
+from Globals import qVersionTuple
 
 from eric6config import getConfig
 
@@ -184,22 +185,17 @@ class WebBrowserTabWidget(E5TabWidget):
         self.__tabContextMenu.addAction(
             self.tr('Close All'), self.closeAllBrowsers)
         self.__tabContextMenu.addSeparator()
-        # TODO: re-check this once printing on Windows is reliable
-##        if qVersion() >= "5.8.0" or (
-##                not Globals.isWindowsPlatform() and qVersion() < "5.7.0"):
-        if not Globals.isWindowsPlatform() and (
-                qVersion() < "5.7.0" or qVersion() >= "5.8.0"):
+        if qVersionTuple() >= (5, 8, 0) or (
+           not Globals.isWindowsPlatform() and qVersionTuple() < (5, 7, 0)):
             self.__tabContextMenu.addAction(
                 UI.PixmapCache.getIcon("printPreview.png"),
                 self.tr('Print Preview'), self.__tabContextMenuPrintPreview)
-        # TODO: re-check this once printing on Windows is reliable
-##        if qVersion() >= "5.8.0" or (
-##                not Globals.isWindowsPlatform() or qVersion() >= "5.7.0"):
-        if not Globals.isWindowsPlatform() and qVersion() >= "5.7.0":
+        if qVersionTuple() >= (5, 8, 0) or (
+           not Globals.isWindowsPlatform() or qVersionTuple() >= (5, 7, 0)):
             self.__tabContextMenu.addAction(
                 UI.PixmapCache.getIcon("print.png"),
                 self.tr('Print'), self.__tabContextMenuPrint)
-        if Globals.isLinuxPlatform() or qVersion() >= "5.7.0":
+        if Globals.isLinuxPlatform() or qVersionTuple() >= (5, 7, 0):
             self.__tabContextMenu.addAction(
                 UI.PixmapCache.getIcon("printPdf.png"),
                 self.tr('Print as PDF'), self.__tabContextMenuPrintPdf)
@@ -377,15 +373,21 @@ class WebBrowserTabWidget(E5TabWidget):
         """
         self.newBrowser()
     
-    def newBrowser(self, link=None, position=-1, background=False):
+    def newBrowser(self, link=None, position=-1, background=False,
+                   restoreSession=False):
         """
         Public method to create a new web browser tab.
         
-        @param link link to be shown (string or QUrl)
+        @param link link to be shown
+        @type str or QUrl
         @keyparam position position to create the new tab at or -1 to add it
-            to the end (integer)
+            to the end
+        @type int
         @keyparam background flag indicating to open the tab in the
-            background (bool)
+            background
+        @type bool
+        @keyparam restoreSession flag indicating a restore session action
+        @type bool
         @return reference to the new browser
         @rtype WebBrowserView
         """
@@ -448,11 +450,17 @@ class WebBrowserTabWidget(E5TabWidget):
         self.__closeButton.setEnabled(True)
         self.__navigationButton.setEnabled(True)
         
-        if not linkName:
-            if Preferences.getWebBrowser("StartupBehavior") == 0:
-                linkName = Preferences.getWebBrowser("HomePage")
-            elif Preferences.getWebBrowser("StartupBehavior") == 1:
-                linkName = "eric:speeddial"
+        if not restoreSession:
+            if not linkName:
+                if Preferences.getWebBrowser("NewTabBehavior") == 0:
+                    linkName = "about:blank"
+                elif Preferences.getWebBrowser("NewTabBehavior") == 1:
+                    linkName = Preferences.getWebBrowser("HomePage")
+                elif Preferences.getWebBrowser("NewTabBehavior") == 2:
+                    linkName = "eric:speeddial"
+        
+        if linkName == "eric:blank":
+            linkName = "about:blank"
         
         if linkName:
             browser.setSource(QUrl(linkName))
@@ -649,7 +657,7 @@ class WebBrowserTabWidget(E5TabWidget):
         if printDialog.exec_() == QDialog.Accepted:
             if hasattr(browser.page(), "print"):
                 # Qt >= 5.8.0
-                browser.page().execPrintPage(printer)
+                browser.page().execPrintPage(printer, 10 * 1000)
             elif hasattr(browser.page(), "printToPdf"):
                 # Qt >= 5.7.0
                 if printer.outputFormat() == QPrinter.PdfFormat:
@@ -816,7 +824,7 @@ class WebBrowserTabWidget(E5TabWidget):
         
         preview = QPrintPreviewDialog(printer, self)
         preview.resize(800, 750)
-        if qVersion() >= "5.8.0":
+        if qVersionTuple() >= (5, 8, 0):
             preview.paintRequested.connect(
                 lambda p: self.__printPreviewRequested(p, browser))
         else:
@@ -1182,3 +1190,60 @@ class WebBrowserTabWidget(E5TabWidget):
         """
         self.__closedTabsButton.setEnabled(avail)
         self.__restoreClosedTabAct.setEnabled(avail)
+    
+    ####################################################
+    ## Methods below implement session related functions
+    ####################################################
+    
+    def getSessionData(self):
+        """
+        Public method to populate the session data.
+        
+        @return dictionary containing the session data
+        @rtype dict
+        """
+        sessionData = {}
+        
+        # 1. current index
+        sessionData["CurrentTabIndex"] = self.currentIndex()
+        
+        # 2. tab data
+        sessionData["Tabs"] = []
+        for index in range(self.count()):
+            browser = self.widget(index)
+            data = browser.getSessionData()
+            sessionData["Tabs"].append(data)
+        
+        return sessionData
+    
+    def loadFromSessionData(self, sessionData):
+        """
+        Public method to load the session data.
+        
+        @param sessionData dictionary containing the session data as
+            generated by getSessionData()
+        @type dict
+        """
+        tabCount = self.count()
+        
+        # 1. load tab data
+        if "Tabs" in sessionData:
+            loadTabOnActivate = \
+                Preferences.getWebBrowser("LoadTabOnActivation")
+            for data in sessionData["Tabs"]:
+                browser = self.newBrowser(restoreSession=True)
+                if loadTabOnActivate:
+                    browser.storeSessionData(data)
+                    title, urlStr, icon = browser.extractSessionMetaData(data)
+                    index = self.indexOf(browser)
+                    self.setTabText(index, title)
+                    self.setTabIcon(index, icon)
+                else:
+                    browser.loadFromSessionData(data)
+        
+        # 2. set tab index
+        if "CurrentTabIndex" in sessionData and \
+                sessionData["CurrentTabIndex"] >= 0:
+            index = tabCount + sessionData["CurrentTabIndex"]
+            self.setCurrentIndex(index)
+            self.browserAt(index).activateSession()
